@@ -164,12 +164,16 @@ class ShareMixin(object):
         common.remove_invalid_options(
             context, search_opts, self._get_share_search_options())
 
-        shares = self.share_api.get_all(
-            context, search_opts=search_opts, sort_key=sort_key,
-            sort_dir=sort_dir)
         total_count = None
         if show_count:
-            total_count = len(shares)
+            count, shares = self.share_api.get_all_with_count(
+                context, search_opts=search_opts, sort_key=sort_key,
+                sort_dir=sort_dir)
+            total_count = count
+        else:
+            shares = self.share_api.get_all(
+                context, search_opts=search_opts, sort_key=sort_key,
+                sort_dir=sort_dir)
 
         if is_detail:
             shares = self._view_builder.detail_list(req, shares, total_count)
@@ -189,8 +193,7 @@ class ShareMixin(object):
             'is_public', 'metadata', 'extra_specs', 'sort_key', 'sort_dir',
             'share_group_id', 'share_group_snapshot_id', 'export_location_id',
             'export_location_path', 'display_name~', 'display_description~',
-            'display_description', 'limit', 'offset'
-        )
+            'display_description', 'limit', 'offset')
 
     @wsgi.Controller.authorize
     def update(self, req, id, body):
@@ -333,12 +336,14 @@ class ShareMixin(object):
 
         if share_network_id:
             try:
-                self.share_api.get_share_network(
+                share_network = self.share_api.get_share_network(
                     context,
                     share_network_id)
             except exception.ShareNetworkNotFound as e:
                 raise exc.HTTPNotFound(explanation=e.msg)
-            kwargs['share_network_id'] = share_network_id
+
+            common.check_share_network_is_active(share_network)
+
             if availability_zone_id:
                 if not db.share_network_subnet_get_by_availability_zone_id(
                         context, share_network_id,
@@ -405,6 +410,8 @@ class ShareMixin(object):
 
         if share_type:
             kwargs['share_type'] = share_type
+        if share_network_id:
+            kwargs['share_network_id'] = share_network_id
         new_share = self.share_api.create(context,
                                           share_proto,
                                           size,
@@ -433,6 +440,11 @@ class ShareMixin(object):
             access_data.pop('metadata', None)
         share = self.share_api.get(context, id)
 
+        share_network_id = share.get('share_network_id')
+        if share_network_id:
+            share_network = db.share_network_get(context, share_network_id)
+            common.check_share_network_is_active(share_network)
+
         if (not allow_on_error_status and
                 self._any_instance_has_errored_rules(share)):
             msg = _("Access rules cannot be added while the share or any of "
@@ -474,6 +486,13 @@ class ShareMixin(object):
         access_id = body.get(
             'deny_access', body.get('os-deny_access'))['access_id']
 
+        share = self.share_api.get(context, id)
+        share_network_id = share.get('share_network_id', None)
+
+        if share_network_id:
+            share_network = db.share_network_get(context, share_network_id)
+            common.check_share_network_is_active(share_network)
+
         try:
             access = self.share_api.access_get(context, access_id)
             if access.share_id != id:
