@@ -18,6 +18,7 @@ from six.moves import http_client
 import webob
 from webob import exc
 
+from manila.api import common
 from manila.api.openstack import api_version_request as api_version
 from manila.api.openstack import wsgi
 from manila.api.v1 import share_manage
@@ -184,18 +185,18 @@ class ShareController(shares.ShareMixin,
                             check_availability_zones_extra_spec=True)
 
     @wsgi.Controller.api_version("2.31", "2.47")  # noqa
-    def create(self, req, body):  # pylint: disable=function-redefined
+    def create(self, req, body):  # pylint: disable=function-redefined  # noqa F811
         return self._create(
             req, body, check_create_share_from_snapshot_support=True)
 
     @wsgi.Controller.api_version("2.24", "2.30")  # noqa
-    def create(self, req, body):  # pylint: disable=function-redefined
+    def create(self, req, body):  # pylint: disable=function-redefined  # noqa F811
         body.get('share', {}).pop('share_group_id', None)
         return self._create(req, body,
                             check_create_share_from_snapshot_support=True)
 
     @wsgi.Controller.api_version("2.0", "2.23")  # noqa
-    def create(self, req, body):  # pylint: disable=function-redefined
+    def create(self, req, body):  # pylint: disable=function-redefined  # noqa F811
         body.get('share', {}).pop('share_group_id', None)
         return self._create(req, body)
 
@@ -256,6 +257,13 @@ class ShareController(shares.ShareMixin,
                 msg = _("Share network %s not "
                         "found.") % new_share_network_id
                 raise exc.HTTPBadRequest(explanation=msg)
+            common.check_share_network_is_active(new_share_network)
+        else:
+            share_network_id = share.get('share_network_id', None)
+            if share_network_id:
+                current_share_network = db.share_network_get(
+                    context, share_network_id)
+                common.check_share_network_is_active(current_share_network)
 
         new_share_type_id = params.get('new_share_type_id', None)
         if new_share_type_id:
@@ -410,12 +418,12 @@ class ShareController(shares.ShareMixin,
         return detail
 
     @wsgi.Controller.api_version("2.8", "2.48")  # noqa
-    def manage(self, req, body):  # pylint: disable=function-redefined
+    def manage(self, req, body):  # pylint: disable=function-redefined  # noqa F811
         detail = self._manage(req, body, allow_dhss_true=False)
         return detail
 
     @wsgi.Controller.api_version("2.49")  # noqa
-    def manage(self, req, body):  # pylint: disable=function-redefined
+    def manage(self, req, body):  # pylint: disable=function-redefined  # noqa F811
         detail = self._manage(req, body, allow_dhss_true=True)
         return detail
 
@@ -426,8 +434,8 @@ class ShareController(shares.ShareMixin,
 
     @wsgi.Controller.api_version('2.49')  # noqa
     @wsgi.action('unmanage')
-    def unmanage(self, req, id,
-                 body=None):  # pylint: disable=function-redefined
+    def unmanage(self, req, id,  # pylint: disable=function-redefined # noqa F811
+                 body=None):
         return self._unmanage(req, id, body, allow_dhss_true=True)
 
     @wsgi.Controller.api_version('2.27')
