@@ -57,6 +57,8 @@ def generate_stats(host_state, properties):
             host_state.sg_consistent_snapshot_support),
         'ipv4_support': host_state.ipv4_support,
         'ipv6_support': host_state.ipv6_support,
+        'security_service_update_support': (
+            host_state.security_service_update_support)
     }
 
     host_caps = host_state.capabilities
@@ -129,7 +131,16 @@ def thin_provisioning(host_state_thin_provisioning):
 
 def capabilities_satisfied(capabilities, extra_specs):
 
+    # These extra-specs are not capabilities for matching hosts
+    ignored_extra_specs = (
+        'availability_zones', 'capabilities:availability_zones',
+    )
+
     for key, req in extra_specs.items():
+        # Ignore some extra_specs if told to
+        if key in ignored_extra_specs:
+            continue
+
         # Either not scoped format, or in capabilities scope
         scope = key.split(':')
 
