@@ -16,7 +16,6 @@
 import ddt
 from oslo_config import cfg
 from oslo_serialization import jsonutils
-import six
 import webob
 
 from manila.api.v1 import share_metadata
@@ -122,7 +121,7 @@ class ShareMetaDataTest(test.TestCase):
         req.method = 'POST'
         req.content_type = "application/json"
         body = {"metadata": {"key9": "value9"}}
-        req.body = six.b(jsonutils.dumps(body))
+        req.body = jsonutils.dumps(body).encode("utf-8")
         res_dict = self.controller.create(req, self.share_id, body)
         expected = self.origin_metadata
         expected.update(body['metadata'])
@@ -140,7 +139,7 @@ class ShareMetaDataTest(test.TestCase):
         req = fakes.HTTPRequest.blank(self.url + '/key1')
         req.method = 'PUT'
         body = {"meta": {"": "value1"}}
-        req.body = six.b(jsonutils.dumps(body))
+        req.body = jsonutils.dumps(body).encode("utf-8")
         req.headers["content-type"] = "application/json"
 
         self.assertRaises(webob.exc.HTTPBadRequest,
@@ -150,7 +149,7 @@ class ShareMetaDataTest(test.TestCase):
         req = fakes.HTTPRequest.blank(self.url + '/key1')
         req.method = 'PUT'
         body = {"meta": {("a" * 260): "value1"}}
-        req.body = six.b(jsonutils.dumps(body))
+        req.body = jsonutils.dumps(body).encode("utf-8")
         req.headers["content-type"] = "application/json"
 
         self.assertRaises(webob.exc.HTTPBadRequest,
@@ -162,7 +161,7 @@ class ShareMetaDataTest(test.TestCase):
         req.method = 'POST'
         req.content_type = "application/json"
         body = {"metadata": {"key9": "value9"}}
-        req.body = six.b(jsonutils.dumps(body))
+        req.body = jsonutils.dumps(body).encode("utf-8")
         self.assertRaises(
             webob.exc.HTTPNotFound,
             self.controller.create,
@@ -178,7 +177,7 @@ class ShareMetaDataTest(test.TestCase):
                 'key99': 'value99',
             },
         }
-        req.body = six.b(jsonutils.dumps(expected))
+        req.body = jsonutils.dumps(expected).encode("utf-8")
         res_dict = self.controller.update_all(req, self.share_id, expected)
 
         self.assertEqual(expected, res_dict)
@@ -188,7 +187,7 @@ class ShareMetaDataTest(test.TestCase):
         req.method = 'PUT'
         req.content_type = "application/json"
         expected = {'metadata': {}}
-        req.body = six.b(jsonutils.dumps(expected))
+        req.body = jsonutils.dumps(expected).encode("utf-8")
         res_dict = self.controller.update_all(req, self.share_id, expected)
 
         self.assertEqual(expected, res_dict)
@@ -198,7 +197,7 @@ class ShareMetaDataTest(test.TestCase):
         req.method = 'PUT'
         req.content_type = "application/json"
         expected = {'meta': {}}
-        req.body = six.b(jsonutils.dumps(expected))
+        req.body = jsonutils.dumps(expected).encode("utf-8")
 
         self.assertRaises(webob.exc.HTTPBadRequest,
                           self.controller.update_all, req, self.share_id,
@@ -213,7 +212,7 @@ class ShareMetaDataTest(test.TestCase):
         req.method = 'PUT'
         req.content_type = "application/json"
         expected = {'metadata': metadata}
-        req.body = six.b(jsonutils.dumps(expected))
+        req.body = jsonutils.dumps(expected).encode("utf-8")
 
         self.assertRaises(webob.exc.HTTPBadRequest,
                           self.controller.update_all, req, self.share_id,
@@ -224,7 +223,7 @@ class ShareMetaDataTest(test.TestCase):
         req.method = 'PUT'
         req.content_type = "application/json"
         body = {'metadata': {'key10': 'value10'}}
-        req.body = six.b(jsonutils.dumps(body))
+        req.body = jsonutils.dumps(body).encode("utf-8")
 
         self.assertRaises(webob.exc.HTTPNotFound,
                           self.controller.update_all, req, '100', body)
@@ -233,7 +232,7 @@ class ShareMetaDataTest(test.TestCase):
         req = fakes.HTTPRequest.blank(self.url + '/key1')
         req.method = 'PUT'
         body = {"meta": {"key1": "value1"}}
-        req.body = six.b(jsonutils.dumps(body))
+        req.body = jsonutils.dumps(body).encode("utf-8")
         req.headers["content-type"] = "application/json"
         res_dict = self.controller.update(req, self.share_id, 'key1', body)
         expected = {'meta': {'key1': 'value1'}}
@@ -243,7 +242,7 @@ class ShareMetaDataTest(test.TestCase):
         req = fakes.HTTPRequest.blank('/v1.1/fake/shares/asdf/metadata/key1')
         req.method = 'PUT'
         body = {"meta": {"key1": "value1"}}
-        req.body = six.b(jsonutils.dumps(body))
+        req.body = jsonutils.dumps(body).encode("utf-8")
         req.headers["content-type"] = "application/json"
 
         self.assertRaises(
@@ -264,7 +263,7 @@ class ShareMetaDataTest(test.TestCase):
         req = fakes.HTTPRequest.blank(self.url + '/key1')
         req.method = 'PUT'
         body = {"meta": {"": "value1"}}
-        req.body = six.b(jsonutils.dumps(body))
+        req.body = jsonutils.dumps(body).encode("utf-8")
         req.headers["content-type"] = "application/json"
 
         self.assertRaises(webob.exc.HTTPBadRequest,
@@ -274,7 +273,7 @@ class ShareMetaDataTest(test.TestCase):
         req = fakes.HTTPRequest.blank(self.url + '/key1')
         req.method = 'PUT'
         body = {"meta": {("a" * 260): "value1"}}
-        req.body = six.b(jsonutils.dumps(body))
+        req.body = jsonutils.dumps(body).encode("utf-8")
         req.headers["content-type"] = "application/json"
 
         self.assertRaises(webob.exc.HTTPBadRequest,
@@ -285,7 +284,7 @@ class ShareMetaDataTest(test.TestCase):
         req = fakes.HTTPRequest.blank(self.url + '/key1')
         req.method = 'PUT'
         body = {"meta": {"key1": ("a" * 1025)}}
-        req.body = six.b(jsonutils.dumps(body))
+        req.body = jsonutils.dumps(body).encode("utf-8")
         req.headers["content-type"] = "application/json"
 
         self.assertRaises(webob.exc.HTTPBadRequest,
@@ -296,7 +295,7 @@ class ShareMetaDataTest(test.TestCase):
         req = fakes.HTTPRequest.blank(self.url + '/key1')
         req.method = 'PUT'
         body = {"meta": {"key1": "value1", "key2": "value2"}}
-        req.body = six.b(jsonutils.dumps(body))
+        req.body = jsonutils.dumps(body).encode("utf-8")
         req.headers["content-type"] = "application/json"
 
         self.assertRaises(webob.exc.HTTPBadRequest,
@@ -307,7 +306,7 @@ class ShareMetaDataTest(test.TestCase):
         req = fakes.HTTPRequest.blank(self.url + '/bad')
         req.method = 'PUT'
         body = {"meta": {"key1": "value1"}}
-        req.body = six.b(jsonutils.dumps(body))
+        req.body = jsonutils.dumps(body).encode("utf-8")
         req.headers["content-type"] = "application/json"
 
         self.assertRaises(webob.exc.HTTPBadRequest,
@@ -321,18 +320,18 @@ class ShareMetaDataTest(test.TestCase):
 
         # test for long key
         data = {"metadata": {"a" * 260: "value1"}}
-        req.body = six.b(jsonutils.dumps(data))
+        req.body = jsonutils.dumps(data).encode("utf-8")
         self.assertRaises(webob.exc.HTTPBadRequest,
                           self.controller.create, req, self.share_id, data)
 
         # test for long value
         data = {"metadata": {"key": "v" * 1025}}
-        req.body = six.b(jsonutils.dumps(data))
+        req.body = jsonutils.dumps(data).encode("utf-8")
         self.assertRaises(webob.exc.HTTPBadRequest,
                           self.controller.create, req, self.share_id, data)
 
         # test for empty key.
         data = {"metadata": {"": "value1"}}
-        req.body = six.b(jsonutils.dumps(data))
+        req.body = jsonutils.dumps(data).encode("utf-8")
         self.assertRaises(webob.exc.HTTPBadRequest,
                           self.controller.create, req, self.share_id, data)
