@@ -13,6 +13,8 @@
 #    License for the specific language governing permissions and limitations
 #    under the License.
 
+import time
+from unittest import mock
 
 try:
     import xml.etree.cElementTree as ET
@@ -20,12 +22,10 @@ except ImportError:
     import xml.etree.ElementTree as ET
 
 import ddt
-import mock
+from eventlet import greenthread
 from oslo_config import cfg
 import six
-import time
 
-from eventlet import greenthread
 from manila import exception
 from manila.share.drivers.qnap import api
 from manila.share.drivers.qnap import qnap
@@ -153,9 +153,21 @@ class QnapShareDriverLoginTestCase(QnapShareDriverBaseTestCase):
     }, {
         'fake_basic_info': fakes.FakeGetBasicInfoResponseTesEs_1_1_3(),
         'expect_result': api.QnapAPIExecutor
+    }, {
+        'fake_basic_info': fakes.FakeGetBasicInfoResponseTesEs_2_0_0(),
+        'expect_result': api.QnapAPIExecutor
+    }, {
+        'fake_basic_info': fakes.FakeGetBasicInfoResponseTesEs_2_1_0(),
+        'expect_result': api.QnapAPIExecutor
     }, {
         'fake_basic_info': fakes.FakeGetBasicInfoResponseEs_1_1_3(),
         'expect_result': api.QnapAPIExecutor
+    }, {
+        'fake_basic_info': fakes.FakeGetBasicInfoResponseEs_2_0_0(),
+        'expect_result': api.QnapAPIExecutor
+    }, {
+        'fake_basic_info': fakes.FakeGetBasicInfoResponseEs_2_1_0(),
+        'expect_result': api.QnapAPIExecutor
     })
     @ddt.unpack
     def test_create_api_executor(self, fake_basic_info, expect_result):
@@ -179,9 +191,15 @@ class QnapShareDriverLoginTestCase(QnapShareDriverBaseTestCase):
     }, {
         'fake_basic_info': fakes.FakeGetBasicInfoResponseTesEs_1_1_1(),
         'expect_result': exception.ShareBackendException
+    }, {
+        'fake_basic_info': fakes.FakeGetBasicInfoResponseTesEs_2_2_0(),
+        'expect_result': exception.ShareBackendException
     }, {
         'fake_basic_info': fakes.FakeGetBasicInfoResponseEs_1_1_1(),
         'expect_result': exception.ShareBackendException
+    }, {
+        'fake_basic_info': fakes.FakeGetBasicInfoResponseEs_2_2_0(),
+        'expect_result': exception.ShareBackendException
     })
     @ddt.unpack
     def test_create_api_executor_negative(self,
@@ -697,15 +715,13 @@ class QnapShareDriverTestCase(QnapShareDriverBaseTestCase):
             expected_call_list,
             mock_api_return.get_share_info.call_args_list)
         mock_api_return.clone_snapshot.assert_called_once_with(
-            'fakeShareName@fakeSnapshotName', 'fakeShareName')
+            'fakeShareName@fakeSnapshotName', 'fakeShareName', 10)
 
     @mock.patch.object(qnap.QnapShareDriver, '_get_location_path')
-    @mock.patch('manila.share.API')
     @mock.patch.object(qnap.QnapShareDriver, '_gen_random_name')
     def test_create_share_from_snapshot_diff_size(
             self,
             mock_gen_random_name,
-            mock_share_api,
             mock_get_location_path):
         """Test create share from snapshot."""
         fake_snapshot = fakes.SnapshotClass(
@@ -722,9 +738,6 @@ class QnapShareDriverTestCase(QnapShareDriverBaseTestCase):
             'False',
             'False',
             'fakeVolName']
-        mock_share_api.return_value.get.return_value = {'size': 5}
-        mock_api_executor.return_value.edit_share.return_value = (
-            None)
 
         self._do_setup('http://1.2.3.4:8080', '1.2.3.4', 'admin',
                        'qnapadmin', 'Storage Pool 1',
@@ -742,19 +755,7 @@ class QnapShareDriverTestCase(QnapShareDriverBaseTestCase):
             expected_call_list,
             mock_api_return.get_share_info.call_args_list)
         mock_api_return.clone_snapshot.assert_called_once_with(
-            'fakeShareName@fakeSnapshotName', 'fakeShareName')
-        expect_share_dict = {
-            'sharename': 'fakeShareName',
-            'old_sharename': 'fakeShareName',
-            'new_size': 10,
-            'thin_provision': True,
-            'compression': True,
-            'deduplication': False,
-            'ssd_cache': False,
-            'share_proto': 'NFS'
-        }
-        mock_api_return.edit_share.assert_called_once_with(
-            expect_share_dict)
+            'fakeShareName@fakeSnapshotName', 'fakeShareName', 10)
 
     def test_create_share_from_snapshot_without_snapshot_id(self):
         """Test create share from snapshot."""
@@ -1096,6 +1097,8 @@ class QnapShareDriverTestCase(QnapShareDriverBaseTestCase):
         mock_api_executor = qnap.QnapShareDriver._create_api_executor
         mock_api_executor.return_value.get_share_info.return_value = (
             self.get_share_info_return_value())
+        mock_api_executor.return_value.get_snapshot_info.return_value = (
+            self.get_snapshot_info_return_value())
         mock_private_storage = mock.Mock()
         mock_private_storage.update.return_value = None
         mock_private_storage.get.side_effect = [
